==> jc-1.4.0.tar.gz: soot/shimple/internal/HeadBlock.h <==
// class soot.shimple.internal.HeadBlock

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ddd7609e6ca992af soot_shimple_internal_HeadBlock
// @dep_class b252d9c4153bf27b soot_toolkits_graph_Block

// header file dependencies
// @dep_header soot_toolkits_graph_Block

#include "soot/toolkits/graph/Block.h"

#ifndef _JC_soot_shimple_internal_HeadBlock_H_
#define _JC_soot_shimple_internal_HeadBlock_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_soot_shimple_internal_HeadBlock$sub_refs	_jc_soot_shimple_internal_HeadBlock$sub_refs;
typedef struct _jc_soot_shimple_internal_HeadBlock$sub_nonrefs	_jc_soot_shimple_internal_HeadBlock$sub_nonrefs;
typedef struct _jc_soot_shimple_internal_HeadBlock$refs	_jc_soot_shimple_internal_HeadBlock$refs;
typedef struct _jc_soot_shimple_internal_HeadBlock$nonrefs	_jc_soot_shimple_internal_HeadBlock$nonrefs;
typedef struct _jc_soot_shimple_internal_HeadBlock$object	_jc_soot_shimple_internal_HeadBlock$object;

typedef const struct _jc_soot_shimple_internal_HeadBlock$vmethods	_jc_soot_shimple_internal_HeadBlock$vmethods;
typedef const struct _jc_soot_shimple_internal_HeadBlock$vtable	_jc_soot_shimple_internal_HeadBlock$vtable;
typedef const struct _jc_soot_shimple_internal_HeadBlock$vtype	_jc_soot_shimple_internal_HeadBlock$vtype;

// Constructors
extern void _jc_soot_shimple_internal_HeadBlock$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_soot_shimple_internal_HeadBlock$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_soot_shimple_internal_HeadBlock$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_soot_shimple_internal_HeadBlock$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_internal_HeadBlock$method_info$iterator$3cc91493d50f531c;

// Virtual methods structure
struct _jc_soot_shimple_internal_HeadBlock$vmethods {
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_soot_shimple_internal_HeadBlock$object *);
};

// Vtable
struct _jc_soot_shimple_internal_HeadBlock$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_Block$vmethods	soot_toolkits_graph_Block;
	_jc_soot_shimple_internal_HeadBlock$vmethods	soot_shimple_internal_HeadBlock;
};

// Vtype
struct _jc_soot_shimple_internal_HeadBlock$vtype {
	_jc_type			type;
	_jc_soot_shimple_internal_HeadBlock$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_internal_HeadBlock$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_internal_HeadBlock$refs {
    _jc_soot_shimple_internal_HeadBlock$sub_refs	soot_shimple_internal_HeadBlock;
    _jc_soot_toolkits_graph_Block$sub_refs	soot_toolkits_graph_Block;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_internal_HeadBlock$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_internal_HeadBlock$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_Block$sub_nonrefs	soot_toolkits_graph_Block;
    _jc_soot_shimple_internal_HeadBlock$sub_nonrefs	soot_shimple_internal_HeadBlock;
};

// Object instance structure
struct _jc_soot_shimple_internal_HeadBlock$object {
	_jc_soot_shimple_internal_HeadBlock$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_internal_HeadBlock$vtype	*vtype;
	_jc_soot_shimple_internal_HeadBlock$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_internal_HeadBlock$vtype _jc_soot_shimple_internal_HeadBlock$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_internal_HeadBlock, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_internal_HeadBlock$class_object;

#endif	/* _JC_soot_shimple_internal_HeadBlock_H_ */

==> jc-1.4.6.tar.gz: soot/shimple/internal/HeadBlock.h <==
// class soot.shimple.internal.HeadBlock

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ddd7609e6ca992af soot_shimple_internal_HeadBlock
// @dep_class b252d9c4153bf27b soot_toolkits_graph_Block

// header file dependencies
// @dep_header soot_toolkits_graph_Block

#include "soot/toolkits/graph/Block.h"

#ifndef _JC_soot_shimple_internal_HeadBlock_H_
#define _JC_soot_shimple_internal_HeadBlock_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_soot_shimple_internal_HeadBlock$sub_refs	_jc_soot_shimple_internal_HeadBlock$sub_refs;
typedef struct _jc_soot_shimple_internal_HeadBlock$sub_nonrefs	_jc_soot_shimple_internal_HeadBlock$sub_nonrefs;
typedef struct _jc_soot_shimple_internal_HeadBlock$refs	_jc_soot_shimple_internal_HeadBlock$refs;
typedef struct _jc_soot_shimple_internal_HeadBlock$nonrefs	_jc_soot_shimple_internal_HeadBlock$nonrefs;
typedef struct _jc_soot_shimple_internal_HeadBlock$object	_jc_soot_shimple_internal_HeadBlock$object;

typedef const struct _jc_soot_shimple_internal_HeadBlock$vmethods	_jc_soot_shimple_internal_HeadBlock$vmethods;
typedef const struct _jc_soot_shimple_internal_HeadBlock$vtable	_jc_soot_shimple_internal_HeadBlock$vtable;
typedef const struct _jc_soot_shimple_internal_HeadBlock$vtype	_jc_soot_shimple_internal_HeadBlock$vtype;

// Constructors
extern void _jc_soot_shimple_internal_HeadBlock$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_soot_shimple_internal_HeadBlock$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_shimple_internal_HeadBlock$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_soot_shimple_internal_HeadBlock$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_internal_HeadBlock$method_info$iterator$3cc91493d50f531c;

// Virtual methods structure
struct _jc_soot_shimple_internal_HeadBlock$vmethods {
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_soot_shimple_internal_HeadBlock$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_shimple_internal_HeadBlock$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_Block$vmethods	soot_toolkits_graph_Block;
	_jc_soot_shimple_internal_HeadBlock$vmethods	soot_shimple_internal_HeadBlock;
};

// Vtype
struct _jc_soot_shimple_internal_HeadBlock$vtype {
	_jc_type			type;
	_jc_soot_shimple_internal_HeadBlock$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_internal_HeadBlock$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_internal_HeadBlock$refs {
    _jc_soot_shimple_internal_HeadBlock$sub_refs	soot_shimple_internal_HeadBlock;
    _jc_soot_toolkits_graph_Block$sub_refs	soot_toolkits_graph_Block;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_internal_HeadBlock$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_internal_HeadBlock$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_Block$sub_nonrefs	soot_toolkits_graph_Block;
    _jc_soot_shimple_internal_HeadBlock$sub_nonrefs	soot_shimple_internal_HeadBlock;
};

// Object instance structure
struct _jc_soot_shimple_internal_HeadBlock$object {
	_jc_soot_shimple_internal_HeadBlock$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_internal_HeadBlock$vtype	*vtype;
	_jc_soot_shimple_internal_HeadBlock$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_internal_HeadBlock$vtype _jc_soot_shimple_internal_HeadBlock$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_internal_HeadBlock, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_internal_HeadBlock$class_object;

#endif	/* _JC_soot_shimple_internal_HeadBlock_H_ */
